==> org-lsst-ccs-drivers-gpvacmon-1.0.2-sources.jar: org/lsst/ccs/drivers/gpvacmon/TestGP835.java <==
package org.lsst.ccs.drivers.gpvacmon;

import org.lsst.ccs.command.annotations.Argument;
import org.lsst.ccs.command.annotations.Command;
import org.lsst.ccs.drivers.commons.DriverException;
import org.lsst.ccs.drivers.commons.DriverTimeoutException;

/**
 *************************************************************************** 
 ** 
 ** Program to test the GP835 device driver
 ** 
 ** @author Homer
 ** 
 *************************************************************************** 
 */
public class TestGP835 {

	protected GP835 mydev;       
        
    @Command(name = "open", description = "Open a device for use")
	public void open(
            @Argument(name="connType", description="type of connection NETWORK(0), FTDI(1), SERIAL(2)") int itype,
            @Argument(name = "devId", description = "The device ID of the device to open") String MyDevId
                ) throws DriverException {
		
    	    mydev = new GP835();
			mydev.open(itype,MyDevId,9600);
    }

    @Command(name="openftdi", description="Open FTDI connection to device")
    public String openftdi(@Argument(name="serialname", description="FTDI id") String host,
          @Argument(name="baud", description="baud") int baud) throws DriverException
    {
    	mydev = new GP835();
        mydev.openftdi(host, baud);
        return mydev.getIdent();
    }


    @Command(name = "close", description = "Close the device")
	public void close() throws Exception {
    	mydev.close();
	}

    @Command(name="getPressure", description = "get the pressure")
    public double getPressure() throws Exception {
        return mydev.getPressure();
    }

    @Command(name = "setGaugeOn", description = "set the gauge on ")
	public void setGaugeOn(
                ) throws Exception {
    	    mydev.setGaugeOn();
	}

    @Command(name = "setGaugeOn", description = "set the gauge on ")
	public void setGaugeOff(
                ) throws Exception {
    	    mydev.setGaugeOff();
	}
}

==> org-lsst-ccs-drivers-gpvacmon-1.0.3-sources.jar: org/lsst/ccs/drivers/gpvacmon/TestGP835.java <==
package org.lsst.ccs.drivers.gpvacmon;

import org.lsst.ccs.command.annotations.Argument;
import org.lsst.ccs.command.annotations.Command;
import org.lsst.ccs.drivers.commons.DriverException;
import org.lsst.ccs.drivers.commons.DriverTimeoutException;

/**
 *************************************************************************** 
 ** 
 ** Program to test the GP835 device driver
 ** 
 ** @author Homer
 ** 
 *************************************************************************** 
 */
public class TestGP835 {

	protected GP835 mydev;       
        
    @Command(name = "open", description = "Open a device for use")
	public void open(
            @Argument(name="connType", description="type of connection NETWORK(0), FTDI(1), SERIAL(2)") int itype,
            @Argument(name = "devId", description = "The device ID of the device to open") String MyDevId
                ) throws DriverException {
		
    	    mydev = new GP835();
			mydev.open(itype,MyDevId,9600);
    }

    @Command(name="openftdi", description="Open FTDI connection to device")
    public String openftdi(@Argument(name="serialname", description="FTDI id") String host,
          @Argument(name="baud", description="baud") int baud) throws DriverException
    {
    	mydev = new GP835();
        mydev.openftdi(host, baud);
        return mydev.getIdent();
    }


    @Command(name = "close", description = "Close the device")
	public void close() throws Exception {
    	mydev.close();
	}

    @Command(name="getPressure", description = "get the pressure")
    public double getPressure() throws Exception {
        return mydev.getPressure();
    }

    @Command(name="getTestReport", description = "get the test report")
    public String getTestReport() throws Exception {
        return mydev.getTestReport();
    }

    @Command(name="getMSP", description = "get the mass spectrometer scan results")
    public String getMSP() throws Exception {
        return mydev.getMSP();
    }

    @Command(name = "setGaugeOn", description = "set the gauge on ")
	public void setGaugeOn(
                ) throws Exception {
    	    mydev.setGaugeOn();
	}

    @Command(name = "setGaugeOn", description = "set the gauge on ")
	public void setGaugeOff(
                ) throws Exception {
    	    mydev.setGaugeOff();
	}
}
